==> ecs-1.122.0-sources.jar: software/amazon/awscdk/services/ecs/Host.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The details on a container instance bind mount host volume.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-08T20:44:44.523Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.Host")
@software.amazon.jsii.Jsii.Proxy(Host.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Host extends software.amazon.jsii.JsiiSerializable {

    /**
     * Specifies the path on the host container instance that is presented to the container.
     * <p>
     * If the sourcePath value does not exist on the host container instance, the Docker daemon creates it.
     * If the location does exist, the contents of the source path folder are exported.
     * <p>
     * This property is not supported for tasks that use the Fargate launch type.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSourcePath() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Host}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Host}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<Host> {
        private java.lang.String sourcePath;

        /**
         * Sets the value of {@link Host#getSourcePath}
         * @param sourcePath Specifies the path on the host container instance that is presented to the container.
         *                   If the sourcePath value does not exist on the host container instance, the Docker daemon creates it.
         *                   If the location does exist, the contents of the source path folder are exported.
         *                   <p>
         *                   This property is not supported for tasks that use the Fargate launch type.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourcePath(java.lang.String sourcePath) {
            this.sourcePath = sourcePath;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Host}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public Host build() {
            return new Jsii$Proxy(sourcePath);
        }
    }

    /**
     * An implementation for {@link Host}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Host {
        private final java.lang.String sourcePath;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.sourcePath = software.amazon.jsii.Kernel.get(this, "sourcePath", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String sourcePath) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.sourcePath = sourcePath;
        }

        @Override
        public final java.lang.String getSourcePath() {
            return this.sourcePath;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getSourcePath() != null) {
                data.set("sourcePath", om.valueToTree(this.getSourcePath()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ecs.Host"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Host.Jsii$Proxy that = (Host.Jsii$Proxy) o;

            return this.sourcePath != null ? this.sourcePath.equals(that.sourcePath) : that.sourcePath == null;
        }

        @Override
        public final int hashCode() {
            int result = this.sourcePath != null ? this.sourcePath.hashCode() : 0;
            return result;
        }
    }
}

==> ecs-1.173.0-sources.jar: software/amazon/awscdk/services/ecs/Host.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The details on a container instance bind mount host volume.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.ecs.*;
 * Host host = Host.builder()
 *         .sourcePath("sourcePath")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:35.861Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.Host")
@software.amazon.jsii.Jsii.Proxy(Host.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Host extends software.amazon.jsii.JsiiSerializable {

    /**
     * Specifies the path on the host container instance that is presented to the container.
     * <p>
     * If the sourcePath value does not exist on the host container instance, the Docker daemon creates it.
     * If the location does exist, the contents of the source path folder are exported.
     * <p>
     * This property is not supported for tasks that use the Fargate launch type.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSourcePath() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Host}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Host}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<Host> {
        java.lang.String sourcePath;

        /**
         * Sets the value of {@link Host#getSourcePath}
         * @param sourcePath Specifies the path on the host container instance that is presented to the container.
         *                   If the sourcePath value does not exist on the host container instance, the Docker daemon creates it.
         *                   If the location does exist, the contents of the source path folder are exported.
         *                   <p>
         *                   This property is not supported for tasks that use the Fargate launch type.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourcePath(java.lang.String sourcePath) {
            this.sourcePath = sourcePath;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Host}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public Host build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Host}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Host {
        private final java.lang.String sourcePath;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.sourcePath = software.amazon.jsii.Kernel.get(this, "sourcePath", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.sourcePath = builder.sourcePath;
        }

        @Override
        public final java.lang.String getSourcePath() {
            return this.sourcePath;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getSourcePath() != null) {
                data.set("sourcePath", om.valueToTree(this.getSourcePath()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ecs.Host"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Host.Jsii$Proxy that = (Host.Jsii$Proxy) o;

            return this.sourcePath != null ? this.sourcePath.equals(that.sourcePath) : that.sourcePath == null;
        }

        @Override
        public final int hashCode() {
            int result = this.sourcePath != null ? this.sourcePath.hashCode() : 0;
            return result;
        }
    }
}
